# Generated by Django 2.2.2 on 2019-06-04 18:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faq', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='faq',
            options={'ordering': ['order']},
        ),
        migrations.AddField(
            model_name='faq',
            name='order',
            field=models.PositiveIntegerField(default=None),
            preserve_default=False,
        ),
    ]
